@@ -1,3 +1,5 @@
+from typing import Optional
+
 from scipy.stats import invgamma, rv_continuous
 
 from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
@@ -41,6 +43,10 @@ class InvGamma(
             a=self._alpha, scale=self._beta
         )
 
+    def mode(self) -> float:
+
+        return self.beta / (self.alpha + 1)
+
     def __str__(self):
 
         return (
